==> google_siteverification_v1_api-0.1.0.tar.gz: lib/src/browser/siteVerification.dart <==
part of siteverification_v1_api_browser;

/** Client to access the siteVerification v1 API */
/** Lets you programatically verify ownership of websites or domains with Google. */
class SiteVerification extends BrowserClient {

  WebResourceResource _webResource;
  WebResourceResource get webResource => _webResource;

  /** OAuth Scope2: Manage the list of sites and domains you control */
  static const String SITEVERIFICATION_SCOPE = "https://www.googleapis.com/auth/siteverification";

  /** OAuth Scope2: Manage your new site verifications with Google */
  static const String SITEVERIFICATION_VERIFY_ONLY_SCOPE = "https://www.googleapis.com/auth/siteverification.verify_only";

  /**
   * Data format for the response.
   * Added as queryParameter for each request.
   */
  String get alt => params["alt"];
  set alt(String value) => params["alt"] = value;

  /**
   * Selector specifying which fields to include in a partial response.
   * Added as queryParameter for each request.
   */
  String get fields => params["fields"];
  set fields(String value) => params["fields"] = value;

  /**
   * API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
   * Added as queryParameter for each request.
   */
  String get key => params["key"];
  set key(String value) => params["key"] = value;

  /**
   * OAuth 2.0 token for the current user.
   * Added as queryParameter for each request.
   */
  String get oauth_token => params["oauth_token"];
  set oauth_token(String value) => params["oauth_token"] = value;

  /**
   * Returns response with indentations and line breaks.
   * Added as queryParameter for each request.
   */
  bool get prettyPrint => params["prettyPrint"];
  set prettyPrint(bool value) => params["prettyPrint"] = value;

  /**
   * Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. Overrides userIp if both are provided.
   * Added as queryParameter for each request.
   */
  String get quotaUser => params["quotaUser"];
  set quotaUser(String value) => params["quotaUser"] = value;

  /**
   * IP address of the site where the request originates. Use this if you want to enforce per-user limits.
   * Added as queryParameter for each request.
   */
  String get userIp => params["userIp"];
  set userIp(String value) => params["userIp"] = value;

  SiteVerification([OAuth2 auth]) : super(auth) {
    basePath = "/siteVerification/v1/";
    rootUrl = "https://www.googleapis.com:443/";
    _webResource = new WebResourceResource(this);
  }
}

==> google_siteverification_v1_api-0.1.3.tar.gz: lib/src/browser/siteVerification.dart <==
part of siteverification_v1_api_browser;

/** Client to access the siteVerification v1 API */
/** Lets you programatically verify ownership of websites or domains with Google. */
class SiteVerification extends BrowserClient {

  WebResourceResource _webResource;
  WebResourceResource get webResource => _webResource;

  /** OAuth Scope2: Manage the list of sites and domains you control */
  static const core.String SITEVERIFICATION_SCOPE = "https://www.googleapis.com/auth/siteverification";

  /** OAuth Scope2: Manage your new site verifications with Google */
  static const core.String SITEVERIFICATION_VERIFY_ONLY_SCOPE = "https://www.googleapis.com/auth/siteverification.verify_only";

  /**
   * Data format for the response.
   * Added as queryParameter for each request.
   */
  core.String get alt => params["alt"];
  set alt(core.String value) => params["alt"] = value;

  /**
   * Selector specifying which fields to include in a partial response.
   * Added as queryParameter for each request.
   */
  core.String get fields => params["fields"];
  set fields(core.String value) => params["fields"] = value;

  /**
   * API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
   * Added as queryParameter for each request.
   */
  core.String get key => params["key"];
  set key(core.String value) => params["key"] = value;

  /**
   * OAuth 2.0 token for the current user.
   * Added as queryParameter for each request.
   */
  core.String get oauth_token => params["oauth_token"];
  set oauth_token(core.String value) => params["oauth_token"] = value;

  /**
   * Returns response with indentations and line breaks.
   * Added as queryParameter for each request.
   */
  core.bool get prettyPrint => params["prettyPrint"];
  set prettyPrint(core.bool value) => params["prettyPrint"] = value;

  /**
   * Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. Overrides userIp if both are provided.
   * Added as queryParameter for each request.
   */
  core.String get quotaUser => params["quotaUser"];
  set quotaUser(core.String value) => params["quotaUser"] = value;

  /**
   * IP address of the site where the request originates. Use this if you want to enforce per-user limits.
   * Added as queryParameter for each request.
   */
  core.String get userIp => params["userIp"];
  set userIp(core.String value) => params["userIp"] = value;

  SiteVerification([oauth.OAuth2 auth]) : super(auth) {
    basePath = "/siteVerification/v1/";
    rootUrl = "https://www.googleapis.com:443/";
    _webResource = new WebResourceResource(this);
  }
}
